<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-urls?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// U
	'urls_description' => 'Gestión de las variantes de URL significativas o no',
	'urls_slogan' => 'Gestión de las variantes de URL significativas o no',
];
